import { PipelineExecutionSummary, GetPipelineStateOutput } from '@aws-sdk/client-codepipeline';
import { Entity } from '@backstage/catalog-model';

/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *   http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

declare const AWS_CODEPIPELINE_ARN_ANNOTATION = "aws.amazon.com/aws-codepipeline-arn";
declare const AWS_CODEPIPELINE_TAGS_ANNOTATION = "aws.amazon.com/aws-codepipeline-tags";
declare const AWS_CODEPIPELINE_ARN_ANNOTATION_LEGACY = "aws.amazon.com/aws-codepipeline";
interface PipelineExecutions {
    pipelineExecutions: Array<PipelineExecutionSummary>;
    pipelineName: string;
    pipelineArn: string;
    pipelineRegion: string;
}
interface PipelineExecutionsResponse {
    pipelineExecutions: Array<PipelineExecutions>;
}
interface PipelineState {
    pipelineName: string;
    pipelineArn: string;
    pipelineRegion: string;
    pipelineState: GetPipelineStateOutput;
}
interface PipelineStateResponse {
    pipelines: Array<PipelineState>;
}

/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *     http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

declare function mockCodePipelineExecutions(): ({
    lastUpdateTime: Date;
    pipelineExecutionId: string;
    sourceRevisions: {
        actionName: string;
        revisionId: string;
        revisionSummary: string;
        revisionUrl: string;
    }[];
    startTime: Date;
    status: "InProgress";
    stopTrigger: undefined;
    trigger: {
        triggerType: "Webhook";
        triggerDetail: string;
    };
} | {
    lastUpdateTime: Date;
    pipelineExecutionId: string;
    sourceRevisions: {
        actionName: string;
        revisionId: string;
        revisionSummary: string;
        revisionUrl: string;
    }[];
    startTime: Date;
    status: "Failed";
    stopTrigger: undefined;
    trigger: {
        triggerType: "CreatePipeline";
        triggerDetail: string;
    };
} | {
    lastUpdateTime: Date;
    pipelineExecutionId: string;
    sourceRevisions: {
        actionName: string;
        revisionId: string;
        revisionSummary: string;
    }[];
    startTime: Date;
    status: "Succeeded";
    stopTrigger: undefined;
    trigger: {
        triggerType: "StartPipelineExecution";
        triggerDetail: string;
    };
})[];
declare function mockCodePipelineStatus(): {
    created: Date;
    pipelineName: string;
    pipelineVersion: number;
    stageStates: ({
        actionStates: {
            actionName: string;
            entityUrl: string;
            latestExecution: {
                lastStatusChange: Date;
                status: "Succeeded";
                actionExecutionId: string;
            };
        }[];
        latestExecution: {
            pipelineExecutionId: string;
            status: "Succeeded";
        };
        stageName: string;
        inboundTransitionState?: undefined;
    } | {
        actionStates: {
            actionName: string;
            entityUrl: string;
            latestExecution: {
                externalExecutionId: string;
                externalExecutionUrl: string;
                lastStatusChange: Date;
                status: "Succeeded";
                summary: string;
                actionExecutionId: string;
            };
        }[];
        inboundTransitionState: {
            enabled: boolean;
        };
        latestExecution: {
            pipelineExecutionId: string;
            status: "Succeeded";
        };
        stageName: string;
    })[];
    updated: Date;
};
declare const mockEntityWithTags: Entity;
declare const mockEntityWithArn: Entity;
declare const mockEntityWithArnLegacy: Entity;

export { AWS_CODEPIPELINE_ARN_ANNOTATION, AWS_CODEPIPELINE_ARN_ANNOTATION_LEGACY, AWS_CODEPIPELINE_TAGS_ANNOTATION, type PipelineExecutions, type PipelineExecutionsResponse, type PipelineState, type PipelineStateResponse, mockCodePipelineExecutions, mockCodePipelineStatus, mockEntityWithArn, mockEntityWithArnLegacy, mockEntityWithTags };
